@@ -1,14 +1,19 @@
 from typing import Dict, IO, Type, Union
 
+from omnipy.data.dataset import Dataset
 from omnipy.data.serializer import TarFileSerializer
-
-from ...data.dataset import Dataset
-from .models import JsonDataset, JsonModel
+from omnipy.modules.json.datasets import JsonBaseDataset, JsonDataset
+from omnipy.modules.json.models import JsonModel
 
 
 class JsonDatasetToTarFileSerializer(TarFileSerializer):
+    """"""
     @classmethod
-    def get_supported_dataset_type(cls) -> Type[Dataset]:
+    def is_dataset_directly_supported(cls, dataset: Dataset) -> bool:
+        return isinstance(dataset, JsonBaseDataset)
+
+    @classmethod
+    def get_dataset_cls_for_new(cls) -> Type[Dataset]:
         return JsonDataset
 
     @classmethod
